@@ -167,6 +167,11 @@ _u2fh_authenticate (u2fh_devs * devs,
   do
     {
       struct u2fdevice *dev;
+
+      if (iterations > 0 && len == 2 && memcmp (buf, NOTSATISFIED, 2) == 0)
+	{
+	  Sleep (1000);
+	}
       for (dev = devs->first; dev != NULL; dev = dev->next)
 	{
 	  unsigned char tmp_buf[MAXDATASIZE];
@@ -205,10 +210,6 @@ _u2fh_authenticate (u2fh_devs * devs,
 	{
 	  return U2FH_TIMEOUT_ERROR;
 	}
-      if (len == 2 && memcmp (buf, NOTSATISFIED, 2) == 0)
-	{
-	  Sleep (1000);
-	}
     }
   while ((flags & U2FH_REQUEST_USER_PRESENCE)
 	 && len == 2 && memcmp (buf, NOTSATISFIED, 2) == 0);
